aboutsummaryrefslogtreecommitdiffstats
path: root/actionpack/lib/action_controller/new_base/renderer.rb
diff options
context:
space:
mode:
Diffstat (limited to 'actionpack/lib/action_controller/new_base/renderer.rb')
-rw-r--r--actionpack/lib/action_controller/new_base/renderer.rb8
1 files changed, 4 insertions, 4 deletions
diff --git a/actionpack/lib/action_controller/new_base/renderer.rb b/actionpack/lib/action_controller/new_base/renderer.rb
index 044c15f409..ed34c46aed 100644
--- a/actionpack/lib/action_controller/new_base/renderer.rb
+++ b/actionpack/lib/action_controller/new_base/renderer.rb
@@ -8,7 +8,7 @@ module ActionController
end
def render(action, options = {})
# TODO: Move this into #render_to_string
if action.is_a?(Hash)
options, action = action, nil
else
@@ -17,10 +17,10 @@ module ActionController
_process_options(options)
- self.response_body = render_to_string(options)
+ self.response_body = render_to_body(options)
end
- def render_to_string(options)
+ def render_to_body(options)
unless options.is_a?(Hash)
options = {:action => options}
end
@@ -59,4 +59,4 @@ module ActionController
end
end
end
-end \ No newline at end of file
+end
@@ -8,7 +8,7 @@ module ActionController
end
def render(action, options = {})
- # TODO: Move this into #render_to_string
+ # TODO: Move this into #render_to_body
if action.is_a?(Hash)
options, action = action, nil